@@ -311,7 +311,7 @@ def greenampt(thetai, thetas, Psi, K, dti, nin, dd, i, iyesno, ss1, ss2, ss3):
     plt.rcParams['axes.unicode_minus'] = False
     todayis = dt.utcnow()
     d1 = todayis.strftime("%Y%m%d%H%M%S")
-    # plt.savefig(f'pichistory/{d1}-greenampt.png',dpi = 300)
+    plt.savefig(f'pichistory/{d1}-greenampt.png',dpi = 300)
     # plt.savefig(f'var/www/flaskapp/pichistory/{d1}-greenampt.png',dpi = 300)
     # plt.show()
     #mpl.rcParams['axes.unicode_minus'] = False
