@@ -385,7 +385,7 @@ def gumbel(pq, unitt, unitx, i1, i2, i3, meanx, sdx, n, dataolist):
         plt.rcParams['axes.unicode_minus'] = False
         todayis = dt.utcnow()
         d1 = todayis.strftime("%Y%m%d%H%M%S")
-        # plt.savefig(f'pichistory/{d1}-gumbel.png',dpi = 300)
+        plt.savefig(f'pichistory/{d1}-gumbel.png',dpi = 300)
         # plt.savefig(f'var/www/flaskapp/pichistory/{d1}-gumbel.png',dpi = 300)
         img = io.BytesIO()
         plt.savefig(img, format='png')
