@@ -2,7 +2,7 @@
 Date         : 2023-01-17 19:23:01
 Author       : BDFD,bdfd2005@gmail.com
 Github       : https://github.com/bdfd
-LastEditTime : 2023-02-01 13:26:34
+LastEditTime : 2023-01-20 12:50:53
 LastEditors  : BDFD
 Description  : 
 FilePath     : \WES_Calculation\preprocess\pre_windspeed.py
@@ -27,7 +27,6 @@ def pre_windspeed(original_input):
     o2 = s2int(o2)
     original_input.update({"o2":o2})
     function_input.update({"o2":o2})
-    o2 = 1
 
     if o2 == 1:
         zw = original_input["zw_1"]
@@ -35,7 +34,7 @@ def pre_windspeed(original_input):
         input_Xlat = None
         input_X = None
         input_Rg = None
-        function_input.update({"zw":12, "Xlat":None, "X":None, "Rg":None})
+        function_input.update({"zw":zw, "Xlat":input_Xlat, "X":input_X, "Rg":input_Rg})
 
     if o2 == 2:
         zw = original_input["zw_2"]
@@ -44,7 +43,7 @@ def pre_windspeed(original_input):
         X = original_input["X_2"]
         X = s2dec(X)
         input_Rg = None
-        function_input.update({"zw":12, "Xlat":None, "X":None, "Rg":None})
+        function_input.update({"zw":zw, "Xlat":input_Xlat, "X":X, "Rg":input_Rg})
 
     if o2 == 3:    
         zw = original_input["zw_3"]
@@ -54,16 +53,19 @@ def pre_windspeed(original_input):
         X= original_input["X_3"]
         X= s2dec(X)
         input_Rg = None
-        function_input.update({"zw":12, "Xlat":None, "X":None, "Rg":None})
+        function_input.update({"zw":zw, "Xlat":Xlat, "X":X, "Rg":input_Rg})
     
     if o2 == 4:
         input_zw = None    
-        Xlat = original_input["Xlat"]
+        #Xlat = original_input["Xlat"]
+        Xlat = original_input["Xlat_4"]
         Xlat = s2dec(Xlat)
         input_X= None
-        Rg = original_input["Rg"]
+        #Rg = original_input["Rg"]
+        Rg = original_input["Rg_4"]
         Rg = s2dec(Rg)
-        function_input.update({"zw":12, "Xlat":None, "X":None, "Rg":None})
+        #function_input.update({"zw":input_zw, "Xlat":input_Xlat, "X":input_X, "Rg":Rg})
+        function_input.update({"zw":input_zw, "Xlat":Xlat, "X":input_X, "Rg":Rg})
         
 
     beta = original_input["beta"]
@@ -86,9 +88,9 @@ def pre_windspeed(original_input):
     wdu = original_input["wdu"]
     wdu = s2dec(wdu)
     zu = original_input["zu"]
-    zu = s2int(zu)
+    zu = s2dec(zu)
     original_input.update({"Taa":Taa})
-    function_input.update({"beta":21, "atm":3, "Ta":20, "zt":20, "Tw":16, "Taa":6.667, "wdu":10, "zu":50})
+    function_input.update({"beta":beta, "atm":atm, "Ta":Ta, "zt":zt, "Tw":Tw, "Taa":input_Taa, "wdu":wdu, "zu":zu})
 
     # print("original_input after process",original_input)
     # print("function input is",function_input)
