@@ -10,10 +10,10 @@ import matplotlib.pyplot as plt
 from matplotlib.ticker import FixedLocator, FixedFormatter
 import numpy as np
 import math
-import statistics
+# import statistics
 import io
 import base64
-import PyQt5
+# import PyQt5
 import seaborn as sns
 from decimal import Decimal
 from datetime import datetime as dt
@@ -658,7 +658,7 @@ def wave(c1, d, X, U, el, gamma, Hs, Tz, Ts, Tp):
     plt.rcParams['axes.unicode_minus'] = False
     todayis = dt.utcnow()
     d1 = todayis.strftime("%Y%m%d%H%M%S")
-    # plt.savefig(f'pichistory/{d1}-wavespectra.png',dpi = 300)
+    plt.savefig(f'pichistory/{d1}-wavespectra.png',dpi = 300)
     # plt.savefig(f'var/www/flaskapp/pichistory/{d1}-wavespectra.png',dpi = 300)
     img = io.BytesIO()
     plt.savefig(img, format='png')
